Index: src/heap.h |
=================================================================== |
--- src/heap.h (revision 6008) |
+++ src/heap.h (working copy) |
@@ -2054,8 +2054,9 @@ |
// Allow access to the caches_ array as an ExternalReference. |
friend class ExternalReference; |
// Inline implementation of the caching. |
friend class TranscendentalCacheStub; |
+ friend class TranscendentalCacheSSE2Stub; |
static TranscendentalCache* caches_[kNumberOfCaches]; |
Element elements_[kCacheSize]; |
@@ -2054,8 +2054,9 @@ |
// Allow access to the caches_ array as an ExternalReference. |
friend class ExternalReference; |
- // Inline implementation of the caching. |
+ // Inline implementation of the cache. |
friend class TranscendentalCacheStub; |